pyphyschemtools package
=======================

.. automodule:: pyphyschemtools
   :members:
   :show-inheritance:
   :undoc-members:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pyphyschemtools.icons_logos_banner

Submodules
----------

pyphyschemtools.Chem3D module
-----------------------------

.. automodule:: pyphyschemtools.Chem3D
   :members:
   :show-inheritance:
   :undoc-members:

pyphyschemtools.ML module
-------------------------

.. automodule:: pyphyschemtools.ML
   :members:
   :show-inheritance:
   :undoc-members:

pyphyschemtools.PeriodicTable module
------------------------------------

.. automodule:: pyphyschemtools.PeriodicTable
   :members:
   :show-inheritance:
   :undoc-members:

pyphyschemtools.aithermo module
-------------------------------

.. automodule:: pyphyschemtools.aithermo
   :members:
   :show-inheritance:
   :undoc-members:

pyphyschemtools.cheminformatics module
--------------------------------------

.. automodule:: pyphyschemtools.cheminformatics
   :members:
   :show-inheritance:
   :undoc-members:

pyphyschemtools.core module
---------------------------

.. automodule:: pyphyschemtools.core
   :members:
   :show-inheritance:
   :undoc-members:

pyphyschemtools.kinetics module
-------------------------------

.. automodule:: pyphyschemtools.kinetics
   :members:
   :show-inheritance:
   :undoc-members:

pyphyschemtools.spectra module
------------------------------

.. automodule:: pyphyschemtools.spectra
   :members:
   :show-inheritance:
   :undoc-members:

pyphyschemtools.survey module
-----------------------------

.. automodule:: pyphyschemtools.survey
   :members:
   :show-inheritance:
   :undoc-members:

pyphyschemtools.sympyUtilities module
-------------------------------------

.. automodule:: pyphyschemtools.sympyUtilities
   :members:
   :show-inheritance:
   :undoc-members:

pyphyschemtools.tools4AS module
-------------------------------

.. automodule:: pyphyschemtools.tools4AS
   :members:
   :show-inheritance:
   :undoc-members:

pyphyschemtools.visualID module
-------------------------------

.. automodule:: pyphyschemtools.visualID
   :members:
   :show-inheritance:
   :undoc-members:

pyphyschemtools.visualID\_Eng module
------------------------------------

.. automodule:: pyphyschemtools.visualID_Eng
   :members:
   :show-inheritance:
   :undoc-members:
